@@ -1,8 +1,7 @@
 from .core.model import Section, Channel
 
-__version__ = '0.1.1'
-__all__ = ['Section', 'Channel', 'Neuron', 'Simulation', 'Species',
-           'channels', 'io']
+__version__ = "0.2.1"
+__all__ = ["Section", "Channel", "Neuron", "Simulation", "Species", "channels", "io"]
 
 try:
     from .data.data import Neuron as _Neuron
@@ -14,7 +13,7 @@ try:
     class Neuron(_Neuron):
         """Neuron."""
 
-        __doc__ = _Neuron.__init__.__doc__
+        __doc__ = _Neuron.__doc__
         DEFAULT_CONCENTRATION = INITIAL_CONCENTRATION
         DEFAULT_DIFFUSION_COEF = DIFFUSION_COEF
 
@@ -27,6 +26,7 @@ try:
             super().__init__(*args, **kwargs)
             self.plot = SimuView(self)
 
+
 except ModuleNotFoundError:  # nogui
     from .data.data import Neuron
     from .data.data import Simulation
