@@ -29,24 +29,31 @@ import networkx as nx
 import sinaps.core.species as species
 
 PI = np.pi
-SpatialError = ValueError("""No spatial resolution for the neuron
-                             init_sim(dx) must be called before""")
+SpatialError = ValueError(
+    """No spatial resolution for the neuron
+                             init_sim(dx) must be called before"""
+)
+
 
 class InitialConcentrationError(ValueError):
     def __init__(self, ion):
         super().__init__(
             """No initial concentration defined for the ion {}
                define it using [section].C0=dict([ion]=[initial_concentration])
-                    """.format(ion))
+                    """.format(
+                ion
+            )
+        )
 
 
 class SectionAttribute(param.Range):
     """Parameter than can be a tuple or a value"""
+
     step = None
 
     def _validate(self, val):
-        if not hasattr(val, '__len__'):
-            super()._validate((val,)*2)
+        if not hasattr(val, "__len__"):
+            super()._validate((val,) * 2)
         else:
             super()._validate(val)
 
@@ -80,12 +87,15 @@ class Neuron(param.Parameterized):
     >>> nrn = Neuron({sec: (0,1)})
 
     """
+
     DEFAULT_CONCENTRATION = {}
     DEFAULT_DIFFUSION_COEF = {}
 
     V_ref = param.Number(0, doc="Resting potential of the neuron [mV]")
     reactions = param.List(
-        [], doc="Chemical reactions to consider in the reaction-electrodiffusion simulation")
+        [],
+        doc="Chemical reactions to consider in the reaction-electrodiffusion simulation",
+    )
 
     def __init__(self, sections=None, **kwargs):
 
@@ -116,7 +126,7 @@ class Neuron(param.Parameterized):
             edges = G.edges
         else:
             edges = self.__traversal_func__(G, self.__traversal_source__)
-        return {G.edges[e]['section']: e for e in edges}
+        return {G.edges[e]["section"]: e for e in edges}
 
     def add_section(self, sec, i, j):
         """Connect nodes.
@@ -126,7 +136,7 @@ class Neuron(param.Parameterized):
         connect nodes i and j with section s
         """
         if not issubclass(type(sec), Section):
-            raise ValueError('Must be a section (sinaps.Section)')
+            raise ValueError("Must be a section (sinaps.Section)")
         self.graph.add_edge(i, j, section=sec)
 
     def add_sections_from_dict(self, sections):
@@ -147,8 +157,7 @@ class Neuron(param.Parameterized):
 
         Parameters
         ----------
-        species : TYPE
-            DESCRIPTION.
+        species : Species
         C0 : number or dict [mMol/L], optional
             Default value for initial concentration if not defined in the
             section. The default is None.
@@ -159,17 +168,19 @@ class Neuron(param.Parameterized):
         Raises
         ------
         InitialConcentrationError
-            DESCRIPTION.
 
         Examples
         -------
         Add species `Ca` :
+
         >>> nrn.add_species(Species.Ca)
-        
+
         Add species `Ca` with initial concentration 1 mMol/L:
+
         >>> nrn = Neuron([(0,1)])
         >>> nrn.add_species(Species.Ca, C0=1)
         >>> nrn.sections
+
         """
         C0 = C0 if C0 is not None else self.DEFAULT_CONCENTRATION
         D = D if D is not None else self.DEFAULT_DIFFUSION_COEF
@@ -215,7 +226,7 @@ class Neuron(param.Parameterized):
 
         """
         self.reactions.append((left, right, k1, k2))
-        self.add_species(list(left.keys())+list(right.keys()))
+        self.add_species(list(left.keys()) + list(right.keys()))
 
     @property
     def species(self):
@@ -224,7 +235,8 @@ class Neuron(param.Parameterized):
 
     @property
     def nb_nodes(self):
-        return max([max(ij) for ij in self.sections.values()])+1
+        """Number of nodes of the neuron"""
+        return max([max(ij) for ij in self.sections.values()]) + 1
 
     def _init_sim(self, dx, force=False):
         """Prepare the neuron to run a simulation with spatial resolution dx."""
@@ -254,19 +266,18 @@ class Neuron(param.Parameterized):
                 for c in s.channels:
                     if type(c) is ch_cls:
                         for p in params:
-                            if hasattr(c, 'position'):  # Point channel
+                            if hasattr(c, "position"):  # Point channel
                                 value = c.params[p]
                             else:  # Continuous channel
                                 value = s._param_array(c.params[p])
                             params[p].append(value)
                         idV.append(c.idV)
                         idS.append(c.idS)
-                        if hasattr(c, 'position'):  # Point channel
+                        if hasattr(c, "position"):  # Point channel
                             surface.append([1])
                         else:  # Continuous channel
                             surface.append(s._surface_array())
-            ch.params = {k: np.hstack(v)[:, np.newaxis]
-                         for k, v in params.items()}
+            ch.params = {k: np.hstack(v)[:, np.newaxis] for k, v in params.items()}
             ch.idV = np.hstack(idV)
             ch.nb_var = ch_cls.nb_var
             if ch.nb_var:
@@ -332,15 +343,15 @@ class Neuron(param.Parameterized):
 
         for s, (i, j) in self.sections.items():
             # longitudinal conductance in a section
-            g_l = 1/s._r_l_array()
+            g_l = 1 / s._r_l_array()
             G[s.idV[:-1], s.idV[1:]] += g_l
             G[s.idV[1:], s.idV[:-1]] += g_l
             G[s.idV[:-1], s.idV[:-1]] += -g_l
             G[s.idV[1:], s.idV[1:]] += -g_l
             #  conductance between connecting nodes and first/last compartment
-            g_end = 1/s._r_l_end()
+            g_end = 1 / s._r_l_end()
             ends = [0, -1]
-            G[s.idV[ends], [i+n, j+n]] += g_end
+            G[s.idV[ends], [i + n, j + n]] += g_end
             G[s.idV[ends], s.idV[ends]] += -g_end
 
         return G
@@ -362,10 +373,10 @@ class Neuron(param.Parameterized):
         k = np.zeros([self.nb_nodes, self.nb_comp])
 
         for s, (i, j) in self.sections.items():
-            g_end = 1/s._r_l_end()
+            g_end = 1 / s._r_l_end()
             # conductance of leak channels
             k[[i, j], s.idV[[0, -1]]] = g_end
-        k = k/k.sum(axis=1, keepdims=True)
+        k = k / k.sum(axis=1, keepdims=True)
         return k
 
     def _fill_V0_array(self, V0):
@@ -426,8 +437,11 @@ class Neuron(param.Parameterized):
         if self.dx is None:
             raise SpatialError
 
-        return np.array([s._difus_end(ion) for s in self.sections])\
-            .swapaxes(0, 1).flatten()
+        return (
+            np.array([s._difus_end(ion) for s in self.sections])
+            .swapaxes(0, 1)
+            .flatten()
+        )
         # return the firs node of all section first
         # then the last node of all sections
 
@@ -457,7 +471,7 @@ class Neuron(param.Parameterized):
         n = self.nb_comp
         m = self.nb_nodes
 
-        Vtt = Vt[1:]-Vt[:-1]
+        Vtt = Vt[1:] - Vt[:-1]
 
         # e=1.6021766208e-19 A.s electron charge
         # e=1.6021766208e-4 pA.ms
@@ -465,27 +479,39 @@ class Neuron(param.Parameterized):
         # kb=1.38064852e-05 GΩ.pA^2.ms
         # e/kb=11.6045 1/(pA.GΩ)=mV^-1
         # k=ez/kbT
-        k = 11.6045 * species.CHARGE[ion]/T
+        k = 11.6045 * species.CHARGE[ion] / T
 
         # flux inside a section
-        d = np.resize(self._difus_array(ion), n+m)  # [μm^3/ms]
-        j = dia_matrix((
-            np.array([cc([[0], d[1:]*(1+k/2*Vtt)]),
-                      cc([d[1:]*(-1+k/2*Vtt), [0]
-                          ])]),
-            [0, -1]), shape=(n+1, n+m)).tolil()
+        d = np.resize(self._difus_array(ion), n + m)  # [μm^3/ms]
+        j = dia_matrix(
+            (
+                np.array(
+                    [
+                        cc([[0], d[1:] * (1 + k / 2 * Vtt)]),
+                        cc([d[1:] * (-1 + k / 2 * Vtt), [0]]),
+                    ]
+                ),
+                [0, -1],
+            ),
+            shape=(n + 1, n + m),
+        ).tolil()
         j[-1] = 0  # No flux for last compartiment
-        jtt = (j[1:]-j[:-1]).tolil()  # flux difference [μm^3/ms]
+        jtt = (j[1:] - j[:-1]).tolil()  # flux difference [μm^3/ms]
 
         # flux for connecting nodes
         d_end = self._difus_end(ion)
-        idA = cc([[s.idV[0] for s in self.sections],
-                  [s.idV[-1] for s in self.sections]])
-        idB = cc([[i+n for s, (i, j) in self.sections.items()],
-                  [j+n for s, (i, j) in self.sections.items()]])
-        Vttk = k/2*(Vt[idA] - Vt[idB])
-        jtt[idA, idB] = d_end*(1-Vttk)
-        jtt[idA, idA] += d_end*(-1-Vttk)
+        idA = cc(
+            [[s.idV[0] for s in self.sections], [s.idV[-1] for s in self.sections]]
+        )
+        idB = cc(
+            [
+                [i + n for s, (i, j) in self.sections.items()],
+                [j + n for s, (i, j) in self.sections.items()],
+            ]
+        )
+        Vttk = k / 2 * (Vt[idA] - Vt[idB])
+        jtt[idA, idB] = d_end * (1 - Vttk)
+        jtt[idA, idA] += d_end * (-1 - Vttk)
         return jtt  # [μm^3/ms]
 
     def indexV(self, species=None):
@@ -495,24 +521,24 @@ class Neuron(param.Parameterized):
         """
         if species is None:
             return (
-                np.concatenate([[s.name]*len(s.idV) for s in self.sections]),
-                np.concatenate([s.x for s in self.sections])
-                )
+                np.concatenate([[s.name] * len(s.idV) for s in self.sections]),
+                np.concatenate([s.x for s in self.sections]),
+            )
         else:
             return (
-                np.concatenate([[sp]*self.nb_comp for sp in species]),
+                np.concatenate([[sp] * self.nb_comp for sp in species]),
                 np.concatenate(
-                    [[s.name]*len(s.idV) for s in self.sections] * len(species)
-                    ),
-                np.concatenate([s.x for s in self.sections]*len(species))
-                )
+                    [[s.name] * len(s.idV) for s in self.sections] * len(species)
+                ),
+                np.concatenate([s.x for s in self.sections] * len(species)),
+            )
 
     def indexV_flat(self):
-        """return position (flattened) for potential vector :"""
+        """return position (flattened) for potential vector"""
         x = 0
         ind = []
         for s in self.sections:
-            ind = np.append(ind, s.x+x)
+            ind = np.append(ind, s.x + x)
             x += s.L
         return ind
 
@@ -524,8 +550,10 @@ class Neuron(param.Parameterized):
         position
         """
         # todo
-        return (np.concatenate([[s.name]*len(s.idS) for s in self.sections]),
-                np.concatenate([s.index for s in self.sections]))
+        return (
+            np.concatenate([[s.name] * len(s.idS) for s in self.sections]),
+            np.concatenate([s.index for s in self.sections]),
+        )
 
 
 class Section(param.Parameterized):
@@ -533,26 +561,40 @@ class Section(param.Parameterized):
 
     Resistance and capacitance given per membrane-area unit
     """
+
     _next_id = 0
 
-    L = param.Number(100, bounds=(0, None), inclusive_bounds=(False, True),
-                     doc='length [μm]')
-    a = SectionAttribute(1, bounds=(0, None), inclusive_bounds=(False, True),
-                         doc='radius [μm]')
-    C_m = SectionAttribute(1, bounds=(0, None), inclusive_bounds=(False, True),
-                           doc='menbrane capacitance [μF/cm²]')
-    R_l = SectionAttribute(150, bounds=(0, None), inclusive_bounds=(False, True),
-                           doc='longitudinal resistance [Ohm.cm]')
-    V0 = param.Number(0,
-                      doc='initial potential [mV]')
-    C0 = param.Dict({}, doc='initial concentration for species [mM/L]')
-    D = param.Dict({}, doc='diffusion coeficient for species [um2/ms]')
-    dx = param.Number(None, bounds=(0, None), inclusive_bounds=(False, True),
-                      doc='Spatial resolution for the simulation. If None the global spatial resolution of the Simulation object is used')
+    L = param.Number(
+        100, bounds=(0, None), inclusive_bounds=(False, True), doc="length [μm]"
+    )
+    a = SectionAttribute(
+        1, bounds=(0, None), inclusive_bounds=(False, True), doc="radius [μm]"
+    )
+    C_m = SectionAttribute(
+        1,
+        bounds=(0, None),
+        inclusive_bounds=(False, True),
+        doc="menbrane capacitance [μF/cm²]",
+    )
+    R_l = SectionAttribute(
+        150,
+        bounds=(0, None),
+        inclusive_bounds=(False, True),
+        doc="longitudinal resistance [Ohm.cm]",
+    )
+    V0 = param.Number(0, doc="initial potential [mV]")
+    C0 = param.Dict({}, doc="initial concentration for species [mM/L]")
+    D = param.Dict({}, doc="diffusion coeficient for species [um2/ms]")
+    dx = param.Number(
+        None,
+        bounds=(0, None),
+        inclusive_bounds=(False, True),
+        doc="Spatial resolution for the simulation. If None the global spatial resolution of the Simulation object is used",
+    )
 
     def __init__(self, **kwargs):
-        if 'name' not in kwargs:
-            kwargs['name'] = "Section{:04d}".format(Section._next_id)
+        if "name" not in kwargs:
+            kwargs["name"] = "Section{:04d}".format(Section._next_id)
         super().__init__(**kwargs)
         Section._next_id += 1
         self.channels_c = []
@@ -561,17 +603,17 @@ class Section(param.Parameterized):
     @property
     def _C_m(self):
         """Menbrane capacitance [pF/um²]"""
-        return self.C_m/100
+        return self.C_m / 100
 
     @property
     def _R_l(self):
         """longitudinal resistance [GOhm.um]"""
-        return self.R_l/1E5
+        return self.R_l / 1e5
 
     @property
     def r_l(self):
         """Longitudinal resistance per unit length [GOhm/μm]"""
-        return self._R_l / (PI * self.a**2)
+        return self._R_l / (PI * self.a ** 2)
 
     @property
     def c_m(self):
@@ -591,15 +633,14 @@ class Section(param.Parameterized):
 * channels: {}
 * point_channels: {}""".format(
             self.name,
-            Quantity(self.L*1E-6, 'm'),
-            Quantity(self.a*1E-6, 'm'),
-            Quantity(self.C_m*1E-6, 'F/cm²'),
-            Quantity(self.c_m*1E-12, 'F'),
-            Quantity(self.R_l, 'Ω.cm'),
-            Quantity(self.r_l*1E-12, 'Ω'),
-            '\n  + '.join([str(c) for c in self.channels_c]),
-            '\n  + '.join(['{}:{}'.format(c.position, c)
-                           for c in self.channels_p])
+            Quantity(self.L * 1e-6, "m"),
+            Quantity(self.a * 1e-6, "m"),
+            Quantity(self.C_m * 1e-6, "F/cm²"),
+            Quantity(self.c_m * 1e-12, "F"),
+            Quantity(self.R_l, "Ω.cm"),
+            Quantity(self.r_l * 1e-12, "Ω"),
+            "\n  + ".join([str(c) for c in self.channels_c]),
+            "\n  + ".join(["{}:{}".format(c.position, c) for c in self.channels_p]),
         )
 
     def add_channel(self, C, x=None):
@@ -610,11 +651,12 @@ class Section(param.Parameterized):
         giving a surfacic current in nA/μm2
         """
         if not issubclass(type(C), Channel):
-            raise ValueError('Must be a channel (sinaps.Channel)')
+            raise ValueError("Must be a channel (sinaps.Channel)")
 
         if type(C) in [type(c) for c in self.channels]:
-            warnings.warn(('The section already had a channel of type {} '
-                           .format(type(C))))
+            warnings.warn(
+                ("The section already had a channel of type {} ".format(type(C)))
+            )
 
         C = deepcopy(C)
         if x is None:
@@ -624,8 +666,7 @@ class Section(param.Parameterized):
             self.channels_p.append(C)
 
     def clear_channels(self):
-        """Clear all channels
-        """
+        """Clear all channels"""
         self.channels_c = []
         self.channels_p = []
 
@@ -635,16 +676,15 @@ class Section(param.Parameterized):
 
     # Initilialisation functions
     def _gen_comp(self, dx, force=False):
-        """ section.dx will be use if existing expect if force is True"""
+        """section.dx will be use if existing expect if force is True"""
         if self.dx is None or force:
             self._dx = dx
         else:
             self._dx = self.dx
         try:
-            self.nb_comp = max(int(np.ceil(self.L/self._dx)), 2)
+            self.nb_comp = max(int(np.ceil(self.L / self._dx)), 2)
         except ZeroDivisionError:
-            raise ValueError(
-                'dx must be defined for section {}'.format(self.name))
+            raise ValueError("dx must be defined for section {}".format(self.name))
         return self.nb_comp
 
     def _init_sim(self, idV0, idS00):
@@ -654,25 +694,24 @@ class Section(param.Parameterized):
         idS00 : first indice for state variables
         """
         n = self.nb_comp
-        self._dx = self.L/n
+        self._dx = self.L / n
         # center of the compartiment, size n
-        self.x = np.linspace(self._dx/2, self.L-self._dx/2, n)
+        self.x = np.linspace(self._dx / 2, self.L - self._dx / 2, n)
         # border of the compartiment, size n+1
-        self.xb = np.linspace(0, self.L, n+1)
+        self.xb = np.linspace(0, self.L, n + 1)
         self.idV = idV0 + np.array(range(n), int)
         idS0 = idS00
         for c in self.channels_c:
-            c.idS = [k*n + idS0 + np.array(range(n), int)
-                     for k in range(c.nb_var)]
+            c.idS = [k * n + idS0 + np.array(range(n), int) for k in range(c.nb_var)]
             c.idV = self.idV
             idS0 += n * c.nb_var  # * state variables
         for c in self.channels_p:
             # index of the compartment related to the point process
-            c.idV = idV0 + int(min(c.position * n, n-1))
+            c.idV = idV0 + int(min(c.position * n, n - 1))
             c.idS = [k + idS0 + np.array([0], int) for k in range(c.nb_var)]
             idS0 += c.nb_var  # * state variables
-        self.nb_var = idS0-idS00
-        return idV0+n, idS0
+        self.nb_var = idS0 - idS00
+        return idV0 + n, idS0
 
     def _continuous(self, param):
         if callable(param):
@@ -680,16 +719,16 @@ class Section(param.Parameterized):
         elif issubclass(type(param), tuple):
             return interpolate.interp1d([0, self.L], param)
         else:
-            return lambda x: param*np.ones_like(x)
+            return lambda x: param * np.ones_like(x)
 
     def _param_array(self, param):
         return self._continuous(param)(self.x)
 
     def _param_array_diff(self, param):
-        return self._continuous(param)((self.x[:-1]+self.x[1:])/2)
+        return self._continuous(param)((self.x[:-1] + self.x[1:]) / 2)
 
     def _param_array_end(self, param):
-        return self._continuous(param)([self.x[0]/2, (self.L + self.x[-1])/2])
+        return self._continuous(param)([self.x[0] / 2, (self.L + self.x[-1]) / 2])
 
     def _fill_V0_array(self, V0):
         """fill the initial potential for each nodes
@@ -729,7 +768,7 @@ class Section(param.Parameterized):
         init_sim(dx) must have been previously called
         """
         # np.diff(self.xb) = size of compartiment
-        return np.diff(self.xb) * self._param_array(self.a)**2 * PI  # [um3]
+        return np.diff(self.xb) * self._param_array(self.a) ** 2 * PI  # [um3]
 
     def _surface_array(self):
         """Return the menbrane surface of each compartment
@@ -743,8 +782,11 @@ class Section(param.Parameterized):
         init_sim(dx) must have been previously called
         """
         # np.diff(self.x) = distance between centers of compartiment
-        return (np.diff(self.x) * self._param_array_diff(self._R_l)
-                / (self._param_array_diff(self.a)**2 * PI))  # [MΩ]
+        return (
+            np.diff(self.x)
+            * self._param_array_diff(self._R_l)
+            / (self._param_array_diff(self.a) ** 2 * PI)
+        )  # [MΩ]
 
     def _r_l_end(self):
         """Return the longitunal resistance between the start/end of the section
@@ -752,9 +794,11 @@ class Section(param.Parameterized):
         init_sim(dx) must have been previously called
         """
         # np.diff(self.x) = distance between centers of compartiment
-        return (np.array([self.x[0], (self.L - self.x[-1])])
-                * self._param_array_end(self._R_l)
-                / (self._param_array_end(self.a)**2 * PI))  # [MΩ]
+        return (
+            np.array([self.x[0], (self.L - self.x[-1])])
+            * self._param_array_end(self._R_l)
+            / (self._param_array_end(self.a) ** 2 * PI)
+        )  # [MΩ]
 
     # Diffusion functions
     def _difus_array(self, ion):
@@ -763,9 +807,13 @@ class Section(param.Parameterized):
         init_sim(dx) must have been previously called
         """
         # np.diff(self.x) = distance between centers of compartiment
-        return (self._param_array_diff(self.D[ion])  # [μm^2/ms]
-                * PI * self._param_array_diff(self.a)**2  # [μm]
-                ) / np.diff(self.x)  # [μm^3/ms]
+        return (
+            self._param_array_diff(self.D[ion])  # [μm^2/ms]
+            * PI
+            * self._param_array_diff(self.a) ** 2  # [μm]
+        ) / np.diff(
+            self.x
+        )  # [μm^3/ms]
 
     def _difus_end(self, ion):
         """Return the diffusion coefficient D*a/dx between the start/end of the section
@@ -774,26 +822,33 @@ class Section(param.Parameterized):
         init_sim(dx) must have been previously called
         """
         # np.diff(self.x) = distance between centers of compartiment
-        return (self._param_array_end(self.D[ion])  # [μm^2/ms]
-                * PI * self._param_array_end(self.a)**2  # [μm]
-                ) / np.array([self.x[0], (self.L - self.x[-1])])  # [μm^3/ms]
+        return (
+            self._param_array_end(self.D[ion])  # [μm^2/ms]
+            * PI
+            * self._param_array_end(self.a) ** 2  # [μm]
+        ) / np.array(
+            [self.x[0], (self.L - self.x[-1])]
+        )  # [μm^3/ms]
 
     def __lt__(self, other):
         return self.name < other.name
 
 
 class Channel:
-    """
-    Generic class describing a channel or a group of channel
-    To implement a channel C, it is necessary to implement  :
-     - a function C.I(V,*st_vars) returning the net  current towards inside
-      ([A] for point channel and [pA/μm2] for density channels ) of the mechanism with
-     V the voltage (:array) and *st_vars the state variable of the mechanism (:array)
-      - If there is state variables a function C.dS(V,*st_vars) returning a
+    """Generic class describing a channel or a group of channel.
+
+    To implement a channel `C`, it is necessary to implement:
+
+    + a function `C.I(V,*st_vars)` returning the net  current towards inside
+      ([pA] for point channel and [pA/μm2] for density channels ) of the mechanism with
+      `V` the voltage (:array) and `*st_vars` the state variable of the mechanism (:array)
+    + If there is state variables a function `C.dS(V,*st_vars)` returning a
       tuple with the differential of each state variable
-       and a function S0 returning a tuple with the initial value for each state
-       variable
+      and a function `S0` returning a tuple with the initial value for each state
+      variable
+
     """
+
     nb_var = 0
     param_names = ()
     params = {}
@@ -825,10 +880,10 @@ class Channel:
             return [self.S0()] * n
 
     def density_str(self):
-        if hasattr(self, 'position'):
-            return ''
+        if hasattr(self, "position"):
+            return ""
         else:
-            return '/μm²'
+            return "/μm²"
 
 
 class _SimuChannel:
@@ -837,7 +892,7 @@ class _SimuChannel:
     def __init__(self, ch_cls):
         self.I = njit(ch_cls._I)
         self.dS = njit(ch_cls._dS)
-        if hasattr(ch_cls, '_J'):
+        if hasattr(ch_cls, "_J"):
             self.J = njit(ch_cls._J)
         self.type = ch_cls
 
@@ -853,8 +908,7 @@ class _SimuChannel:
         """
         V = V_S[self.idV, :]
         S = [V_S[self.idS[k], :] for k in range(self.nb_var)]
-        np.add.at(y, np.s_[self.idV, :], self.I(
-            V, *S, t, **self.params) * self.k)
+        np.add.at(y, np.s_[self.idV, :], self.I(V, *S, t, **self.params) * self.k)
         if self.nb_var:
             dS = self.dS(V, *S, t, **self.params)
             if self.nb_var > 1:
@@ -865,19 +919,22 @@ class _SimuChannel:
 
     def fill_J(self, y, ions, V_S, t):
         """fill the array y with :
-            - The flux of ion of the channels self
-            V_S : current values for potential and state variables
-            t : current time (ms)"""
+        - The flux of ion of the channels self
+        V_S : current values for potential and state variables
+        t : current time (ms)"""
         # continuous channels
-        if hasattr(self, 'J'):
+        if hasattr(self, "J"):
             V = V_S[self.idV]
             S = [V_S[self.idS[k]] for k in range(self.nb_var)]
             for k, ion in enumerate(ions):
-                np.add.at(y, np.s_[self.idV, k], (self.J(ion, V, *S, t, **self.params)
-                                                  * self.k).squeeze())
+                np.add.at(
+                    y,
+                    np.s_[self.idV, k],
+                    (self.J(ion, V, *S, t, **self.params) * self.k).squeeze(),
+                )
 
 
-@jitclass({'charge': int8, 'D': float32})
+@jitclass({"charge": int8, "D": float32})
 class _Species:
     """Represents a species."""
 
@@ -894,7 +951,10 @@ class _Species:
 
 if __name__ == "__main__":
     import doctest
-    doctest.testmod(extraglobs={
-        'nrn': Neuron(),
-        'Species': species.Species,
-        })
+
+    doctest.testmod(
+        extraglobs={
+            "nrn": Neuron(),
+            "Species": species.Species,
+        }
+    )
